<?php
/**
 * Plugin Name: Simple Contact Form
 * Plugin URI: https://teesharp.com/simple-contact-form
 * Description: A minimal, no-bloat contact form with email notifications
 * Version: 1.0.0
 * Author: Teesharp Limited
 * Author URI: https://teesharp.com
 * Text Domain: simple-contact-form
 * Domain Path: /languages
 * License: GPL v2 or later
 * License URI: http://www.gnu.org/licenses/gpl-2.0.txt
 */

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

class Simple_Contact_Form
{

    public function __construct()
    {
        // Register shortcode
        add_shortcode('simple_contact_form', array($this, 'render_contact_form'));

        // Register scripts and styles
        add_action('wp_enqueue_scripts', array($this, 'enqueue_scripts'));

        // AJAX handlers
        add_action('wp_ajax_simple_contact_form_submit', array($this, 'handle_form_submission'));
        add_action('wp_ajax_nopriv_simple_contact_form_submit', array($this, 'handle_form_submission'));

        // Add settings page
        add_action('admin_menu', array($this, 'add_settings_page'));
        add_action('admin_init', array($this, 'register_settings'));
    }

    /**
     * Enqueue necessary scripts and styles
     */
    public function enqueue_scripts()
    {
        wp_enqueue_style(
            'simple-contact-form-style',
            plugin_dir_url(__FILE__) . 'assets/css/simple-contact-form.css',
            array(),
            '1.0.0'
        );

        wp_enqueue_script(
            'simple-contact-form-script',
            plugin_dir_url(__FILE__) . 'assets/js/simple-contact-form.js',
            array('jquery'),
            '1.0.0',
            true
        );

        wp_localize_script(
            'simple-contact-form-script',
            'simpleContactForm',
            array(
                'ajaxurl' => admin_url('admin-ajax.php'),
                'nonce' => wp_create_nonce('simple-contact-form-nonce')
            )
        );
    }

    /**
     * Render the contact form
     */
    public function render_contact_form($atts)
    {
        $atts = shortcode_atts(
            array(
                'title' => __('Contact Us', 'simple-contact-form'),
                'submit_text' => __('Send Message', 'simple-contact-form')
            ),
            $atts,
            'simple_contact_form'
        );

        ob_start();
        ?>
        <div class="simple-contact-form-container">
            <h3><?php echo esc_html($atts['title']); ?></h3>

            <div class="simple-contact-form-message" style="display: none;"></div>

            <form id="simple-contact-form" class="simple-contact-form">
                <div class="form-group">
                    <label for="scf-name"><?php _e('Name', 'simple-contact-form'); ?> *</label>
                    <input type="text" id="scf-name" name="name" required>
                </div>

                <div class="form-group">
                    <label for="scf-email"><?php _e('Email', 'simple-contact-form'); ?> *</label>
                    <input type="email" id="scf-email" name="email" required>
                </div>

                <div class="form-group">
                    <label for="scf-subject"><?php _e('Subject', 'simple-contact-form'); ?> *</label>
                    <input type="text" id="scf-subject" name="subject" required>
                </div>

                <div class="form-group">
                    <label for="scf-message"><?php _e('Message', 'simple-contact-form'); ?> *</label>
                    <textarea id="scf-message" name="message" rows="5" required></textarea>
                </div>

                <div class="form-group">
                    <?php wp_nonce_field('simple_contact_form', 'simple_contact_form_nonce'); ?>
                    <button type="submit" class="simple-contact-form-submit">
                        <?php echo esc_html($atts['submit_text']); ?>
                    </button>
                </div>
            </form>
        </div>
        <?php
        return ob_get_clean();
    }

    /**
     * Handle form submission via AJAX
     */
    public function handle_form_submission()
    {
        // Verify nonce
        if (!isset($_POST['nonce']) || !wp_verify_nonce($_POST['nonce'], 'simple-contact-form-nonce')) {
            wp_send_json_error(array(
                'message' => __('Security check failed. Please refresh the page and try again.', 'simple-contact-form')
            ));
        }

        // Validate required fields
        $required_fields = array('name', 'email', 'subject', 'message');
        foreach ($required_fields as $field) {
            if (empty($_POST[$field])) {
                wp_send_json_error(array(
                    'message' => __('Please fill in all required fields.', 'simple-contact-form')
                ));
            }
        }

        // Validate email
        if (!is_email($_POST['email'])) {
            wp_send_json_error(array(
                'message' => __('Please enter a valid email address.', 'simple-contact-form')
            ));
        }

        // Sanitize input
        $name = sanitize_text_field($_POST['name']);
        $email = sanitize_email($_POST['email']);
        $subject = sanitize_text_field($_POST['subject']);
        $message = sanitize_textarea_field($_POST['message']);

        // Get recipient email from settings (or use admin email as default)
        $recipient = get_option('simple_contact_form_recipient_email', get_option('admin_email'));

        // Build email
        $email_subject = sprintf(__('[Contact Form] %s', 'simple-contact-form'), $subject);

        $email_body = sprintf(
            __("Name: %s\nEmail: %s\nSubject: %s\n\nMessage:\n%s", 'simple-contact-form'),
            $name,
            $email,
            $subject,
            $message
        );

        $headers = array(
            'Content-Type: text/plain; charset=UTF-8',
            'From: ' . $name . ' <' . $email . '>',
            'Reply-To: ' . $email
        );

        // Send email
        $sent = wp_mail($recipient, $email_subject, $email_body, $headers);

        if ($sent) {
            wp_send_json_success(array(
                'message' => __('Your message has been sent successfully!', 'simple-contact-form')
            ));
        } else {
            wp_send_json_error(array(
                'message' => __('Failed to send your message. Please try again later.', 'simple-contact-form')
            ));
        }
    }

    /**
     * Add settings page
     */
    public function add_settings_page()
    {
        add_options_page(
            __('Simple Contact Form Settings', 'simple-contact-form'),
            __('Simple Contact Form', 'simple-contact-form'),
            'manage_options',
            'simple-contact-form',
            array($this, 'render_settings_page')
        );
    }

    /**
     * Register settings
     */
    public function register_settings()
    {
        register_setting('simple_contact_form_settings', 'simple_contact_form_recipient_email', array(
            'sanitize_callback' => 'sanitize_email'
        ));
    }

    /**
     * Render settings page
     */
    public function render_settings_page()
    {
        ?>
        <div class="wrap">
            <h1><?php _e('Simple Contact Form Settings', 'simple-contact-form'); ?></h1>

            <form method="post" action="options.php">
                <?php settings_fields('simple_contact_form_settings'); ?>
                <?php do_settings_sections('simple_contact_form_settings'); ?>

                <table class="form-table">
                    <tr valign="top">
                        <th scope="row"><?php _e('Recipient Email', 'simple-contact-form'); ?></th>
                        <td>
                            <input type="email" name="simple_contact_form_recipient_email"
                                value="<?php echo esc_attr(get_option('simple_contact_form_recipient_email', get_option('admin_email'))); ?>"
                                class="regular-text">
                            <p class="description">
                                <?php _e('Email address where contact form submissions will be sent.', 'simple-contact-form'); ?>
                            </p>
                        </td>
                    </tr>
                </table>

                <?php submit_button(); ?>
            </form>

            <div class="simple-contact-form-usage">
                <h2><?php _e('How to Use', 'simple-contact-form'); ?></h2>
                <p>
                    <?php _e('Use the following shortcode to display the contact form on any page or post:', 'simple-contact-form'); ?>
                </p>
                <code>[simple_contact_form]</code>

                <p>
                    <?php _e('You can customize the form title and submit button text using shortcode attributes:', 'simple-contact-form'); ?>
                </p>
                <code>[simple_contact_form title="Get in Touch" submit_text="Send"]</code>
            </div>
        </div>
        <?php
    }

    /**
     * Plugin activation
     */
    public static function activate()
    {
        // Create necessary files and directories
        $plugin_dir = plugin_dir_path(__FILE__);

        // Create assets directory
        if (!file_exists($plugin_dir . 'assets')) {
            mkdir($plugin_dir . 'assets');
            mkdir($plugin_dir . 'assets/css');
            mkdir($plugin_dir . 'assets/js');
        }

        // Create CSS file
        $css_content = <<<CSS
.simple-contact-form-container {
    max-width: 600px;
    margin: 0 auto;
}

.simple-contact-form .form-group {
    margin-bottom: 20px;
}

.simple-contact-form label {
    display: block;
    margin-bottom: 5px;
    font-weight: 600;
}

.simple-contact-form input[type="text"],
.simple-contact-form input[type="email"],
.simple-contact-form textarea {
    width: 100%;
    padding: 8px;
    border: 1px solid #ddd;
    border-radius: 4px;
}

.simple-contact-form-submit {
    background-color: #0073aa;
    color: white;
    border: none;
    padding: 10px 15px;
    border-radius: 4px;
    cursor: pointer;
}

.simple-contact-form-submit:hover {
    background-color: #005177;
}

.simple-contact-form-message {
    padding: 10px;
    margin-bottom: 20px;
    border-radius: 4px;
}

.simple-contact-form-message.success {
    background-color: #dff0d8;
    color: #3c763d;
    border: 1px solid #d6e9c6;
}

.simple-contact-form-message.error {
    background-color: #f2dede;
    color: #a94442;
    border: 1px solid #ebccd1;
}
CSS;
        file_put_contents($plugin_dir . 'assets/css/simple-contact-form.css', $css_content);

        // Create JS file
        $js_content = <<<JS
(function($) {
    'use strict';
    
    $(document).ready(function() {
        $('#simple-contact-form').on('submit', function(e) {
            e.preventDefault();
            
            var form = $(this);
            var messageContainer = $('.simple-contact-form-message');
            var submitButton = form.find('.simple-contact-form-submit');
            
            // Clear previous messages
            messageContainer.removeClass('success error').hide();
            
            // Disable submit button
            submitButton.prop('disabled', true).text('Sending...');
            
            // Collect form data
            var formData = {
                name: form.find('#scf-name').val(),
                email: form.find('#scf-email').val(),
                subject: form.find('#scf-subject').val(),
                message: form.find('#scf-message').val(),
                nonce: simpleContactForm.nonce,
                action: 'simple_contact_form_submit'
            };
            
            // Send AJAX request
            $.post(simpleContactForm.ajaxurl, formData, function(response) {
                if (response.success) {
                    messageContainer.addClass('success').html(response.data.message).show();
                    form[0].reset();
                } else {
                    messageContainer.addClass('error').html(response.data.message).show();
                }
            }).fail(function() {
                messageContainer.addClass('error').html('An unexpected error occurred. Please try again later.').show();
            }).always(function() {
                submitButton.prop('disabled', false).text('Send Message');
            });
        });
    });
})(jQuery);
JS;
        file_put_contents($plugin_dir . 'assets/js/simple-contact-form.js', $js_content);

        // Set default options
        if (!get_option('simple_contact_form_recipient_email')) {
            update_option('simple_contact_form_recipient_email', get_option('admin_email'));
        }
    }
}

// Initialize the plugin
$simple_contact_form = new Simple_Contact_Form();

// Register activation hook
register_activation_hook(__FILE__, array('Simple_Contact_Form', 'activate'));